======
pywhip
======


.. image:: https://img.shields.io/pypi/v/pywhip.svg
        :target: https://pypi.python.org/pypi/pywhip

.. image:: https://img.shields.io/travis/inbo/pywhip.svg
        :target: https://travis-ci.org/inbo/pywhip

.. image:: https://pyup.io/repos/github/inbo/pywhip/shield.svg
     :target: https://pyup.io/repos/github/inbo/pywhip/
     :alt: Updates


Python package to validate data against `whip specifications`_

.. _`whip specifications`: https://github.com/inbo/whip

* Free software: MIT license
* Documentation: https://inbo.github.io/pywhip


Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

